searchData={"items":[{"type":"module","title":"ShinAuth","doc":"A collection of lightweight auth utilities for Elixir.","ref":"ShinAuth.html"},{"type":"module","title":"ShinAuth.OIDC","doc":"OpenID Connect utilities.\n\nPerforms decoding and validation based on the spec: https://openid.net/specs/openid-connect-discovery-1_0.html","ref":"ShinAuth.OIDC.html"},{"type":"function","title":"ShinAuth.OIDC.load_provider_configuration/1","doc":"Loads provider configuration according to\nthe [OpenID Connect Discovery 1.0 spec](https://openid.net/specs/openid-connect-discovery-1_0.html).","ref":"ShinAuth.OIDC.html#load_provider_configuration/1"},{"type":"module","title":"ShinAuth.OIDC.ProviderConfiguration.Metadata","doc":"OpenID Connect Provider Configuration\n\nFor details on the fields see:\n* https://openid.net/specs/openid-connect-discovery-1_0.html#ProviderMetadata\n* https://datatracker.ietf.org/doc/html/draft-jones-oauth-discovery-01#section-4.1\n* https://openid.net/specs/openid-connect-rpinitiated-1_0.html#OPMetadata","ref":"ShinAuth.OIDC.ProviderConfiguration.Metadata.html"},{"type":"type","title":"ShinAuth.OIDC.ProviderConfiguration.Metadata.t/0","doc":"","ref":"ShinAuth.OIDC.ProviderConfiguration.Metadata.html#t:t/0"},{"type":"module","title":"ShinAuth.SAML","doc":"Security Assertion Markup Language utilities.\n\nPerforms decoding and validation based on the spec: https://docs.oasis-open.org/security/saml/v2.0/saml-core-2.0-os.pdf","ref":"ShinAuth.SAML.html"},{"type":"function","title":"ShinAuth.SAML.decode_saml_request/1","doc":"Performs decoding on a given SAML request XML document","ref":"ShinAuth.SAML.html#decode_saml_request/1"},{"type":"function","title":"ShinAuth.SAML.decode_saml_response/1","doc":"Performs decoding on a given SAML response XML document","ref":"ShinAuth.SAML.html#decode_saml_response/1"},{"type":"module","title":"ShinAuth.SAML.Request","doc":"Parsed XML struct of a SAML request","ref":"ShinAuth.SAML.Request.html"},{"type":"type","title":"ShinAuth.SAML.Request.t/0","doc":"","ref":"ShinAuth.SAML.Request.html#t:t/0"},{"type":"module","title":"ShinAuth.SAML.Request.Common","doc":"Defines the common attributes from `samlp:AuthnRequest`","ref":"ShinAuth.SAML.Request.Common.html"},{"type":"type","title":"ShinAuth.SAML.Request.Common.t/0","doc":"","ref":"ShinAuth.SAML.Request.Common.html#t:t/0"},{"type":"module","title":"ShinAuth.SAML.Response","doc":"Parsed XML struct of a SAML response","ref":"ShinAuth.SAML.Response.html"},{"type":"type","title":"ShinAuth.SAML.Response.t/0","doc":"","ref":"ShinAuth.SAML.Response.html#t:t/0"},{"type":"module","title":"ShinAuth.SAML.Response.Attribute","doc":"Defines the attributes and values from `saml:AttributeStatement`","ref":"ShinAuth.SAML.Response.Attribute.html"},{"type":"type","title":"ShinAuth.SAML.Response.Attribute.t/0","doc":"","ref":"ShinAuth.SAML.Response.Attribute.html#t:t/0"},{"type":"module","title":"ShinAuth.SAML.Response.Common","doc":"Defines the common attributes from `samlp:Response`","ref":"ShinAuth.SAML.Response.Common.html"},{"type":"type","title":"ShinAuth.SAML.Response.Common.t/0","doc":"","ref":"ShinAuth.SAML.Response.Common.html#t:t/0"},{"type":"module","title":"ShinAuth.SAML.Response.Conditions","doc":"Defines the attributes and values from `saml:Conditions`","ref":"ShinAuth.SAML.Response.Conditions.html"},{"type":"type","title":"ShinAuth.SAML.Response.Conditions.t/0","doc":"","ref":"ShinAuth.SAML.Response.Conditions.html#t:t/0"},{"type":"module","title":"ShinAuth.SAML.Response.Status","doc":"Defines the attributes and values from `samlp:Status`","ref":"ShinAuth.SAML.Response.Status.html"},{"type":"type","title":"ShinAuth.SAML.Response.Status.t/0","doc":"","ref":"ShinAuth.SAML.Response.Status.html#t:t/0"},{"type":"exception","title":"ShinAuth.OIDC.ProviderConfiguration.Error","doc":"Defines the possible errors from decoding provider configuration","ref":"ShinAuth.OIDC.ProviderConfiguration.Error.html"},{"type":"type","title":"ShinAuth.OIDC.ProviderConfiguration.Error.t/0","doc":"","ref":"ShinAuth.OIDC.ProviderConfiguration.Error.html#t:t/0"},{"type":"exception","title":"ShinAuth.SAML.Request.Error","doc":"Defines the possible errors from decoding a SAML request","ref":"ShinAuth.SAML.Request.Error.html"},{"type":"type","title":"ShinAuth.SAML.Request.Error.t/0","doc":"","ref":"ShinAuth.SAML.Request.Error.html#t:t/0"},{"type":"exception","title":"ShinAuth.SAML.Response.Error","doc":"Defines the possible errors from decoding a SAML response","ref":"ShinAuth.SAML.Response.Error.html"},{"type":"type","title":"ShinAuth.SAML.Response.Error.t/0","doc":"","ref":"ShinAuth.SAML.Response.Error.html#t:t/0"},{"type":"extras","title":"Shin","doc":"# Shin\n\n🍀 A collection of lightweight auth utilities for Elixir.","ref":"readme.html"},{"type":"extras","title":"Introduction - Shin","doc":"**Shin** **信** means \"trust\", \"faith\", or \"belief\" in Japanese. \n\nThis package aims to provide lightweight utilities that can be used to ensure that primitives are well validated and trusted for usage by auth providers.","ref":"readme.html#introduction"},{"type":"extras","title":"Playground - Shin","doc":"A UI playground with usage example per utility can be found at https://shin.howauth.com","ref":"readme.html#playground"},{"type":"extras","title":"Getting started - Shin","doc":"The package can be installed by adding `shin_auth` to your list of dependencies in `mix.exs`:\n\n```elixir \ndef deps do\n  [\n    {:shin_auth, \"~> 1.3.0\"}\n  ]\nend\n```","ref":"readme.html#getting-started"},{"type":"extras","title":"Utilities per protocol - Shin","doc":"#","ref":"readme.html#utilities-per-protocol"},{"type":"extras","title":"OpenID Connect (OIDC) - Shin","doc":"#### `load_provider_configuration` \n\nBased on the spec: https://openid.net/specs/openid-connect-discovery-1_0.html#ProviderMetadata\n\nLoads, validates and parses the Identity Provider configuration based on their discovery endpoint metadata. \n\nWith valid configuration, returns parsed metadata:\n```ex\niex(1)> ShinAuth.OIDC.load_provider_configuration(\"https://valid-url/.well-known/openid-configuration\")\n{:ok, %ShinAuth.OIDC.ProviderConfiguration.Metadata{}}\n```\n\nWith invalid configuration, returns error:\n\n```ex\niex(1)> ShinAuth.OIDC.load_provider_configuration(\"https://invalid-discovery/.well-known/openid-configuration\")\n{:error, %ShinAuth.OIDC.ProviderConfiguration.Error{}}\n```\n\nHere's a list of error per tags:\n\n| Tags                                | Reason                                                                 |\n|------------------------------------|------------------------------------------------------------------------|\n| `malformed_discovery_endpoint` or `discovery_endpoint_unreachable`      | The provided endpoint is either malformed or unreachable via HTTP request       |\n| `authorization_endpoint_unreachable` | `authorization_code` is unreachable via HTTP request |\n| `token_endpoint_unreachable`       |  `token_endpoint` is unreachable via HTTP request           |\n| `jwks_uri_unreachable` or `malformed_jwks_uri_response`       | `jwks_uri` is either unreachable via HTTP request or the response is malformed |\n| `missing_issuer_attribute`         | `issuer` attribute is missing from the provider's metadata |\n\n\n#","ref":"readme.html#openid-connect-oidc"},{"type":"extras","title":"Security Assertion Markup Language (SAML) - Shin","doc":"### `decode_saml_response`\n\nParsed a given SAML response to a struct with attributes and values: \n\n```ex\niex(1)> ShinAuth.SAML.decode_saml_response(saml_response_xml)\n\n{:ok, %ShinAuth.SAML.Response{\n   common: %ShinAuth.SAML.Response.Common{\n     id: \"_123\",\n     version: \"2.0\",\n     destination: \"https://api.example.com/sso/saml/acs/123\",\n     issuer: \"https://example.com/1234/issuer/1234\",\n     issue_instant: \"2024-03-23T20:56:56.768Z\"\n   },\n   status: %ShinAuth.SAML.Response.Status{\n     status: :success,\n     status_code: \"urn:oasis:names:tc:SAML:2.0:status:Success\"\n   },\n   conditions: %ShinAuth.SAML.Response.Conditions{\n     not_before: \"2024-03-23T20:56:56.768Z\",\n     not_on_or_after: \"2024-03-23T21:01:56.768Z\"\n   },\n   attributes: [\n     %ShinAuth.SAML.Response.Attribute{\n       name: \"id\",\n       value: \"209bac63df9962e7ec458951607ae2e8ed00445a\"\n     },\n     %ShinAuth.SAML.Response.Attribute{\n       name: \"email\",\n       value: \"foo@corp.com\"\n     },\n     %ShinAuth.SAML.Response.Attribute{\n       name: \"firstName\",\n       value: \"Laura\"\n     },\n     %ShinAuth.SAML.Response.Attribute{\n       name: \"lastName\",\n       value: \"Beatris\"\n     },\n     %ShinAuth.SAML.Response.Attribute{name: \"groups\", value: \"\"}\n   ]\n }}\n```\n\n### `decode_saml_request`\n\nParsed a given SAML request to a struct with attributes and values: \n\n```ex\niex(1)> ShinAuth.SAML.decode_saml_request(saml_request_xml)\n\n{:ok, %ShinAuth.SAML.Request{\n   common: %ShinAuth.SAML.Request.Common{\n     id: \"_123\",\n     version: \"2.0\",\n     assertion_consumer_service_url: \"https://auth.example.com/sso/saml/acs/123\",\n     issuer: \"https://example.com/123\",\n     issue_instant: \"2023-09-27T17:20:42.746Z\"\n   }\n }}\n```","ref":"readme.html#security-assertion-markup-language-saml"},{"type":"extras","title":"LICENSE","doc":"Copyright (c) 2024-present Laura Beatris\n\nLicensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at\n\n    http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.","ref":"license.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}